@@ -17,6 +17,6 @@ from .persist import load, save
 from .namespace import Name_Space, get_container
 from .container import Container
 from .view import View
-from .automate import Automator
+from .automate import Automator, Aliases
 from .utils import Factory
 
