@@ -25,8 +25,9 @@ def safe_call(method_name, obj, *args, **kwargs):
         pass
 
 class Automator():
-    def __init__(self, container, fname=None, sets=None):
+    def __init__(self, container, fname=None, sets=None, aliases=None):
         self.container = container
+        self._aliases = Aliases() if aliases is None else aliases
         if fname is not None and sets is None:
             self.sets = persist.load(fname)
         elif fname is None and sets is not None:
@@ -40,6 +41,23 @@ class Automator():
         for vec_name, item_name in label_dct.items():
             print('   ' + (vec_name + ': ').ljust(25) + str(item_name))
         
+    def get_sequencer(self, set_name):
+        data = self.sets[set_name]
+        vec_data = {}
+        if 'vectors' in data:
+            vec_data.update(data['vectors'])
+        if 'constants' in data:
+            ds = data['constants'].copy()
+            for k, d in ds.items():
+                d['style'] = 'constant'
+            vec_data.update(ds)
+        aliases = self._aliases.copy()
+        if 'aliases' in self.sets:
+            aliases.update(self.sets['aliases'])
+        vectors = Vectors(vec_data)
+        s = Sequencer(data['sequences'], aliases, vectors)
+        return s
+        
     def run(self, set_name, obj):
         ''' Run an automation set 
         
@@ -47,13 +65,7 @@ class Automator():
             set_name (str): The name of the set to run
             obj (object): The automated class instance.
         '''
-        data = self.sets[set_name]
-        vec_data = {}
-        if 'vectors' in data:
-            vec_data.update(data['vectors'])
-        if 'constants' in data:
-            vec_data.update(data['constants'])
-        s = Sequencer(data['sequences'], self.sets['aliases'], vec_data)
+        s = self.get_sequencer(set_name)
         safe_call('prepare', obj)
         for seq_name, seq_dct in s.all_sequences().items():
             self.execute_sequence(seq_name, seq_dct, obj)
@@ -92,7 +104,17 @@ class Aliases(dict):
                 out[k] = v
         return out
     
+    def copy(self):
+        return Aliases(self)
     
+    def add_csv(self, fname, dotkey='dotkey', alias='alias', **kwargs):
+        df = pd.read_csv(fname, usecols=[dotkey, alias])
+        dct = {r[alias]: r[dotkey] for i, r in df.iterrows()}
+        self.update(dct)
+
+    def __missing__(self, key):
+        return key
+
 class Vector():
     ''' Subclass for different entry formats '''
     def __init__(self, name):
@@ -164,8 +186,11 @@ class Value_Dictionaries(Vector):
 
 class Constant(Vector):
     def setup(self, data):
-        k, v = data.copy().popitem()
-        labels = [v]
+        if len(data) == 1:
+            k, v = data.copy().popitem()
+            labels = [v]
+        else:
+            labels = [True]
         d = [data.copy()]
         return labels, d
 
@@ -173,7 +198,12 @@ class Csv_File(Vector):
     def setup(self, data):
         d = []
         full_filename = os.path.join(root, data['filename'])
-        df = pd.read_csv(full_filename, index_col=0)
+        try:
+            df = pd.read_csv(full_filename, index_col=0)
+        except FileNotFoundError:
+            raise FileNotFoundError("File '" + full_filename + "' does not "
+                "exist. To set the root directory, use " +
+                "vt.automate.set_root(path)")
         labels = list(df.index)
         for index, row in df.iterrows():
             d.append(row.to_dict())
@@ -220,7 +250,7 @@ class Vector_Factory():
             elif len(data) == 1:
                 return Constant
             else:
-                raise ValueError('Input style not understood: ' + str(data))
+                return Constant
             
     
 class Vectors():
@@ -243,8 +273,8 @@ class Vectors():
 class Sequencer():
     def __init__(self, sequences, aliases, vectors):
         self.sequences = sequences
-        self.aliases = Aliases(aliases)
-        self.vectors = Vectors(vectors)
+        self.aliases = aliases
+        self.vectors = vectors
         
     def sequence(self, name):
         seq_dct = {}
